@@ -29,7 +29,9 @@
 #include <atk/atkrelation.h>
 #include <atk/atkrelationset.h>
 #include <atk/atkselection.h>
+#include <atk/atkstate.h>
 #include <atk/atkstateset.h>
+#include <atk/atkstreamablecontent.h>
 #include <atk/atktable.h>
 #include <atk/atktext.h>
 #include <atk/atkutil.h>
