@@ -34,278 +34,164 @@ extern "C" {
  * accessibility information about a component if it supports one or more
  * of the following interfaces:
  */
-typedef enum
-{
-  ATK_CHILD_ADDED,
-  ATK_CHILD_REMOVED,
-  ATK_CHILD_CHANGED
-} AtkChildChangeType;
 
+/* AtkAttributeSet & AtkAttribute are needed by atktext and atkeditable text */
+/* so I am putting them here until a better place for them to be defined is  */
+/* decided */
+typedef GSList AtkAttributeSet;
+
+typedef struct _AtkAttribute {
+  gchar* name;
+  gchar* value;
+}AtkAttribute;
+
+/**
+ *AtkRole:
+ *@ATK_ROLE_INVALID: Invalid role
+ *@ATK_ROLE_ACCEL_LABEL: A label which represents an accelerator
+ *@ATK_ROLE_ALERT: An object which is an alert to the user
+ *@ATK_ROLE_ANIMATION: An object which is an animated image
+ *@ATK_ROLE_ARROW: An arrow in one of the four cardinal directions
+ *@ATK_ROLE_CALENDAR:  An object that displays a calendar and allows the user to select a date
+ *@ATK_ROLE_CANVAS: An object that can be drawn into and is used to trap events
+ *@ATK_ROLE_CHECK_BOX: A choice that can be checked or unchecked and provides a separate indicator for the current state
+ *@ATK_ROLE_CHECK_MENU_ITEM: A menu item with a check box
+ *@ATK_ROLE_COLOR_CHOOSER: A specialized dialog that lets the user choose a color
+ *@ATK_ROLE_COLUMN_HEADER: The header for a column of data
+ *@ATK_ROLE_COMBO_BOX: A list of choices the user can select from
+ *@ATK_ROLE_DATE_EDITOR: An object whose purpose is to allow a user to edit a date
+ *@ATK_ROLE_DESKTOP_ICON: An inconifed internal frame within a DESKTOP_PANE
+ *@ATK_ROLE_DESKTOP_FRAME: A pane that supports internal frames and iconified versions of those internal frames
+ *@ATK_ROLE_DIAL: An object whose purpose is to allow a user to set a value
+ *@ATK_ROLE_DIALOG: A top level window with title bar and a border
+ *@ATK_ROLE_DIRECTORY_PANE: A pane that allows the user to navigate through and select the contents of a directory
+ *@ATK_ROLE_DRAWING_AREA: An object used for drawing custom user interface elements
+ *@ATK_ROLE_FILE_CHOOSER: A specialized dialog that lets the user choose a file
+ *@ATK_ROLE_FILLER: A object that fills up space in a user interface
+ *@ATK_ROLE_FONT_CHOOSER: A specialized dialog that lets the user choose a font
+ *@ATK_ROLE_FRAME: A top level window with a title bar, border, menubar, etc.
+ *@ATK_ROLE_GLASS_PANE: A pane that is guaranteed to be painted on top of all panes beneath it
+ *@ATK_ROLE_HTML_CONTAINER: A document container for HTML, whose children represent the document content
+ *@ATK_ROLE_ICON: A small fixed size picture, typically used to decorate components
+ *@ATK_ROLE_IMAGE: An object whose primary purpose is to display an image
+ *@ATK_ROLE_INTERNAL_FRAME: A frame-like object that is clipped by a desktop pane
+ *@ATK_ROLE_LABEL: An object used to present an icon or short string in an interface
+ *@ATK_ROLE_LAYERED_PANE: A specialized pane that allows its children to be drawn in layers, providing a form of stacking order
+ *@ATK_ROLE_LIST: An object that presents a list of objects to the user and allows the user to select one or more of them 
+ *@ATK_ROLE_LIST_ITEM: An object that represents an element of a list 
+ *@ATK_ROLE_MENU: An object usually found inside a menu bar that contains a list of actions the user can choose from
+ *@ATK_ROLE_MENU_BAR: An object usually drawn at the top of the primary dialog box of an application that contains a list of menus the user can choose from 
+ *@ATK_ROLE_MENU_ITEM: An object usually contained in a menu that presents an action the user can choose
+ *@ATK_ROLE_OPTION_PANE: A specialized pane whose primary use is inside a DIALOG
+ *@ATK_ROLE_PAGE_TAB: An object that is a child of a page tab list
+ *@ATK_ROLE_PAGE_TAB_LIST: An object that presents a series of panels (or page tabs), one at a time, through some mechanism provided by the object 
+ *@ATK_ROLE_PANEL: A generic container that is often used to group objects
+ *@ATK_ROLE_PASSWORD_TEXT: A text object uses for passwords, or other places where the text content is not shown visibly to the user
+ *@ATK_ROLE_POPUP_MENU: A temporary window that is usually used to offer the user a list of choices, and then hides when the user selects one of those choices
+ *@ATK_ROLE_PROGRESS_BAR: An object used to indicate how much of a task has been completed
+ *@ATK_ROLE_PUSH_BUTTON: An object the user can manipulate to tell the application to do something
+ *@ATK_ROLE_RADIO_BUTTON: A specialized check box that will cause other radio buttons in the same group to become uncghecked when this one is checked
+ *@ATK_ROLE_RADIO_MENU_ITEM: A check menu item which belongs to a group. At each instant exactly one of the radio menu items from a group is selected
+ *@ATK_ROLE_ROOT_PANE: A specialized pane that has a glass pane and a layered pane as its children
+ *@ATK_ROLE_ROW_HEADER: The header for a row of data
+ *@ATK_ROLE_SCROLL_BAR: An object usually used to allow a user to incrementally view a large amount of data.
+ *@ATK_ROLE_SCROLL_PANE: An object that allows a user to incrementally view a large amount of information
+ *@ATK_ROLE_SEPARATOR: An object usually contained in a menu to provide a visible and logical separation of the contents in a menu
+ *@ATK_ROLE_SLIDER: An object that allows the user to select from a bounded range
+ *@ATK_ROLE_SPLIT_PANE: A specialized panel that presents two other panels at the same time
+ *@ATK_ROLE_SPIN_BUTTON: An object used to get an integer or floating point number from the user
+ *@ATK_ROLE_STATUSBAR: An object which reports messages of minor importance to the user
+ *@ATK_ROLE_TABLE: An object used to rpesent information in terms of rows and columns
+ *@ATK_ROLE_TABLE_CELL: A cell in a table
+ *@ATK_ROLE_TABLE_COLUMN_HEADER: The header for a column of a table
+ *@ATK_ROLE_TABLE_ROW_HEADER: The header for a row of a table
+ *@ATK_ROLE_TEAR_OFF_MENU_ITEM: A menu item used to tear off and reattach its menu
+ *@ATK_ROLE_TEXT: An object that presents text to the user
+ *@ATK_ROLE_TOGGLE_BUTTON: A specialized push button that can be checked or unchecked, but does not procide a separate indicator for the current state
+ *@ATK_ROLE_TOOL_BAR: A bar or palette usually composed of push buttons or toggle buttons
+ *@ATK_ROLE_TOOL_TIP: An object that provides information about another object
+ *@ATK_ROLE_TREE: An object used to repsent hierarchical information to the user
+ *@ATK_ROLE_UNKNOWN: The object contains some Accessible information, but its role is not known
+ *@ATK_ROLE_VIEWPORT: An object usually used in a scroll pane
+ *@ATK_ROLE_WINDOW: A top level window with no title or border
+ *@ATK_ROLE_LAST_DEFINED: not a valid role, used for finding end of enumeration
+ * 
+ *Describes the role of an object
+ **/
 typedef enum
 {
   ATK_ROLE_INVALID,
-  /* Object is used to alert the user about something */
+  ATK_ROLE_ACCEL_LABEL,
   ATK_ROLE_ALERT,
-  /* Object that can be drawn into and is sued to trap events */
+  ATK_ROLE_ANIMATION,
+  ATK_ROLE_ARROW,
+  ATK_ROLE_CALENDAR,
   ATK_ROLE_CANVAS,
-  /*
-   * A choice that can be checked or unchecked and provides a separate
-   * indicator for the current state.
-   */
   ATK_ROLE_CHECK_BOX,
-  /* A specialized dialog that lets the user choose a color. */
+  ATK_ROLE_CHECK_MENU_ITEM,
   ATK_ROLE_COLOR_CHOOSER,
-  /* The header for a column of data */
   ATK_ROLE_COLUMN_HEADER,
-  /* A list of choices the user can select from */
   ATK_ROLE_COMBO_BOX,
-  /* An inconifed internal frame within a DESKTOP_PANE */
+  ATK_ROLE_DATE_EDITOR,
   ATK_ROLE_DESKTOP_ICON,
-  /*
-   * A pane that supports internal frames and iconified versions of those
-   * internal frames.
-   */
   ATK_ROLE_DESKTOP_FRAME,
-  /* A top level window with title bar and a border */
+  ATK_ROLE_DIAL,
   ATK_ROLE_DIALOG,
-  /*
-   * A pane that allows the user to navigate through and select the contents
-   * of a directory
-   */
   ATK_ROLE_DIRECTORY_PANE,
-  /*
-   * A specialized dialog that displays the files in the directory and lets
-   * the user select a file, browse a different directory, or specify a
-   * filename.
-   */
+  ATK_ROLE_DRAWING_AREA,
   ATK_ROLE_FILE_CHOOSER,
-  /*
-   * A object that fills up space in a user interface
-   */
   ATK_ROLE_FILLER,
-  /* XXX Don't know sure about this. */
-  ATK_ROLE_FOCUS_TRAVERSABLE,
-  /* A top level window with a title bar, border, menubar, etc. */
+  ATK_ROLE_FONT_CHOOSER,
   ATK_ROLE_FRAME,
-  /* A pane that is guaranteed to be painted on top of all panes beneath it */
   ATK_ROLE_GLASS_PANE,
-  /*
-   * A document container for HTML, whose children
-   * represent the document content.
-   */
   ATK_ROLE_HTML_CONTAINER,
-  /* A small fixed size picture, typically used to decorate components */
   ATK_ROLE_ICON,
-  /* A frame-like object that is clipped by a desktop pane. */
+  ATK_ROLE_IMAGE,
   ATK_ROLE_INTERNAL_FRAME,
-  /* An object used to present an icon or short string in an interface */
   ATK_ROLE_LABEL,
-  /*
-   * A specialized pane that allows its children to be drawn in layers,
-   * providing a form of stacking order.
-   */
   ATK_ROLE_LAYERED_PANE,
-  /*
-   * An object that presents a list of objects to the user and allows the
-   * user to select one or more of them.
-   */
   ATK_ROLE_LIST,
-   /* An object that represents an element of a list. */
   ATK_ROLE_LIST_ITEM,
-  /*
-   * An object usually found inside a menu bar that contains a list of
-   * actions the user can choose from.
-   */
   ATK_ROLE_MENU,
-  /*
-   * An object usually drawn at the top of the primary dialog box of an
-   * application that contains a list of menus the user can choose from.
-   */
   ATK_ROLE_MENU_BAR,
-  /*
-   * An object usually contained in a menu that presents an action the
-   * user can choose.
-   */
   ATK_ROLE_MENU_ITEM,
-  /* A specialized pane whose primary use is inside a DIALOG */
   ATK_ROLE_OPTION_PANE,
-  /* An object that is a child of a page tab list */
   ATK_ROLE_PAGE_TAB,
-  /*
-   * An object that presents a series of panels (or page tabs), one at a time,
-   * through some mechanism provided by the object.
-   */
   ATK_ROLE_PAGE_TAB_LIST,
-  /* A generic container that is often used to group objects. */
   ATK_ROLE_PANEL,
-  /*
-   * A text object uses for passwords, or other places where the text
-   * content is not shown visibly to the user.
-   */
   ATK_ROLE_PASSWORD_TEXT,
-  /*
-   * A temporary window that is usually used to offer the user a list of
-   * choices, and then hides when the user selects one of those choices.
-   */
   ATK_ROLE_POPUP_MENU,
-  /* An object used to indicate how much of a task has been completed. */
   ATK_ROLE_PROGRESS_BAR,
-  /*
-   * An object the user can manipulate to tell the application to do
-   * something.
-   */
   ATK_ROLE_PUSH_BUTTON,
-  /*
-   * A specialized check box that will cause other radio buttons in the
-   * same group to become uncghecked when this one is checked.
-   */
   ATK_ROLE_RADIO_BUTTON,
-  /*
-   * A specialized pane that has a glass pane and a layered pane as its
-   * children.
-   */
+  ATK_ROLE_RADIO_MENU_ITEM,
   ATK_ROLE_ROOT_PANE,
-  /* The header for a row of data */
   ATK_ROLE_ROW_HEADER,
-  /*
-   * An object usually used to allow a user to incrementally view a large
-   * amount of data.
-   */
   ATK_ROLE_SCROLL_BAR,
-  /*
-   * An object that allows a user to incrementally view a large amount
-   * of information.
-   */
   ATK_ROLE_SCROLL_PANE,
-  /*
-   * An object usually contained in a menu to provide a visible and
-   * logical separation of the contents in a menu.
-   */
   ATK_ROLE_SEPARATOR,
-  /* An object that allows the user to select from a bounded range */
   ATK_ROLE_SLIDER,
-  /* A specialized panel that presents two other panels at the same time. */
   ATK_ROLE_SPLIT_PANE,
-  /* An object used to rpesent information in terms of rows and columns. */
+  ATK_ROLE_SPIN_BUTTON,
+  ATK_ROLE_STATUSBAR,
   ATK_ROLE_TABLE,
   ATK_ROLE_TABLE_CELL,
   ATK_ROLE_TABLE_COLUMN_HEADER,
   ATK_ROLE_TABLE_ROW_HEADER,
-  /* An object that presents text to the user */
+  ATK_ROLE_TEAR_OFF_MENU_ITEM,
   ATK_ROLE_TEXT,
-  /*
-   * A specialized push button that can be checked or unchecked, but does
-   * not procide a separate indicator for the current state.
-   */
   ATK_ROLE_TOGGLE_BUTTON,
-  /*
-   * A bar or palette usually composed of push buttons or toggle buttons
-   */
   ATK_ROLE_TOOL_BAR,
-  /*
-   * An object that provides information about another object
-   */
   ATK_ROLE_TOOL_TIP,
-  /* An object used to repsent hierarchical information to the user. */
   ATK_ROLE_TREE,
-  /*
-   * The object contains some Accessible information, but its role is
-   * not known.
-   */
   ATK_ROLE_UNKNOWN,
-  /* An object usually used in a scroll pane. */
   ATK_ROLE_VIEWPORT,
-  /* A top level window with no title or border */
   ATK_ROLE_WINDOW,
-  /* not a valid role, used for finding end of enumeration. */
   ATK_ROLE_LAST_DEFINED
 } AtkRole;
 
 AtkRole                  atk_role_register        (const gchar *name);
 
-typedef enum
-{
-  ATK_STATE_INVALID,
-  /* Indicates a window is currently the active window */
-  ATK_STATE_ACTIVE,
-  /* Indicates that the object is armed */
-  ATK_STATE_ARMED,
-  /* Indicates the current object is busy */
-  ATK_STATE_BUSY,
-  /* Indicates this object is currently checked */
-  ATK_STATE_CHECKED,
-  /* Indicates this object is collapsed */
-  ATK_STATE_COLLAPSED,
-  /* Indicates the user can change the contents of this object */
-  ATK_STATE_DEFUNCT,
-  /* Indicates this object may have been removed by the application */
-  ATK_STATE_EDITABLE,
-  /* Indicates this object allows progressive disclosure of its children */
-  ATK_STATE_EXPANDABLE,
-  /* Indicates this object is expandable */
-  ATK_STATE_EXPANDED,
-  /*
-   * Indicates this object can accept keyboard focus, which means all
-   * events resulting from typing on the keyboard will normally be passed
-   * to it when it has focus
-   */
-  ATK_STATE_FOCUSABLE,
-  /* Indicates this object currently has the keyboard focus */
-  ATK_STATE_FOCUSED,
-  /* Indicates the orientation of thsi object is horizontal */
-  ATK_STATE_HORIZONTAL,
-  /* Indicates this object is minimized and is represented only by an icon */
-  ATK_STATE_ICONIFIED,
-  /*
-   * Indicates something must be done with this object before the user can
-   * interact with an object in a different window.
-   */
-  ATK_STATE_MODAL,
-  /* Indicates this (text) object can contain multiple lines of text */
-  ATK_STATE_MULTI_LINE,
-  /*
-   * Indicates this object allows more than one of its children to be
-   * selected at the same time
-   */
-  ATK_STATE_MULTISELECTABLE,
-  /* Indicates this object paints every pixel within its rectangular region. */
-  ATK_STATE_OPAQUE,
-  /* Indicates this object is currently pressed */
-  ATK_STATE_PRESSED,
-  /* Indicates the size of this object is not fixed */
-  ATK_STATE_RESIZABLE,
-  /*
-   * Indicates this object is the child of an object that allows its
-   * children to be selected and that this child is one of those children
-   * that can be selected.
-   */
-  ATK_STATE_SELECTABLE,
-  /*
-   * Indicates this object is the child of an object that allows its
-   * children to be selected and that this child is one of those children
-   * that has been selected.
-   */
-  ATK_STATE_SELECTED,
-  /* Indicates this object is sensitive */
-  ATK_STATE_SENSITIVE,
-  /*
-   * Indicates this object, the object's parent, the object's parent's
-   * parent, and so on, are all visible
-   */
-  ATK_STATE_SHOWING,
-  /* Indicates this (text) object can contain only a single line of text */
-  ATK_STATE_SINGLE_LINE,
-  /* Indicates this object is transient */
-  ATK_STATE_TRANSIENT,
-  /* Indicates the orientation of this object is vertical */
-  ATK_STATE_VERTICAL,
-  /* Indicates this object is visible */
-  ATK_STATE_VISIBLE,
-  ATK_STATE_LAST_DEFINED
-} AtkStateType;
-
-AtkStateType               atk_state_type_register      (const gchar *name);
-
 
 #define ATK_TYPE_OBJECT                           (atk_object_get_type ())
 #define ATK_OBJECT(obj)                           (G_TYPE_CHECK_INSTANCE_CAST ((obj), ATK_TYPE_OBJECT, AtkObject))
@@ -329,10 +215,6 @@ typedef struct _AtkObjectClass            AtkObjectClass;
 typedef struct _AtkRelationSet            AtkRelationSet;
 typedef struct _AtkStateSet               AtkStateSet;
 
-typedef guint64                           AtkState;
-typedef guint64                           AtkStateMask;
-
-
 struct _AtkPropertyValues
 {
   gchar  *property_name;
@@ -452,9 +334,16 @@ void                      (* remove_property_change_handler)     (AtkObject
    * children of the object
    */
   void                    (* children_changed)    (AtkObject                  *accessible,
-                                                   AtkChildChangeType         change_type,
+                                                   gint                       change_index,
                                                    AtkObject                  *changed_child);
+  /*
+   * The signal handler which is executed  when there is a focus event
+   * for an object.
+   */
+  void                    (*focus_event)          (AtkObject                  *accessible,
+                                                   gboolean                   focus_in);
 };
+
 GType            atk_object_get_type   (void);
 
 struct _AtkImplementorIface
@@ -564,9 +453,6 @@ void                 atk_object_remove_property_change_handler  (AtkObject
  *    cpos = atk_text_get_caret_position (ATK_TEXT (accessible));
  */
 
-G_CONST_RETURN gchar* atk_state_mask_get_name         (AtkStateMask    state);
-AtkStateMask          atk_state_mask_for_name         (const gchar     *name);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
